# -*- coding: utf-8 -*-
from django.contrib import admin
from django.utils.translation import gettext_lazy as _
from jmb.filters.admin import AdvancedSearchModelAdmin
from mptt.admin import MPTTModelAdmin
from thx.core.admin import UserAdminMixin

from . import models


class ProfileAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    search_fields = ()
    advanced_search_fields = ()
    list_filter = ('status',)
    fieldsets = (
        (_('general information'), {
            'fields': ('codename', 'name', 'users',)
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = ('pk', 'codename', 'name', 'status', 'ordering')
    list_display_links = ('codename', 'name',)
    filter_horizontal = ('users',)
    readonly_fields = ('codename', 'creator', 'date_create', 'last_modifier', 'date_last_modify')


class RequiredFieldInline(admin.TabularInline):
    model = models.RequiredField
    fields = ('status', 'from_status', 'fields', 'ordering',)
    extra = 0


class StatusFlowInline(admin.TabularInline):
    model = models.StatusFlow
    fields = ('status', 'from_status', 'to_status', 'ordering',)
    extra = 0


class UsedFieldInline(admin.TabularInline):
    model = models.UsedField
    fields = ('status', 'from_status', 'action', 'fields', 'ordering',)
    extra = 0


class FilterInline(admin.TabularInline):
    model = models.Filter
    fields = ('status', 'action', 'codename', 'description', 'code', 'ordering',)
    readonly_fields = ('codename',)
    extra = 0


class RoleAdmin(UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin):
    search_fields = ('profile__name',)
    advanced_search_fields = (
        ('status',),
        ('profile__name__icontains',),
        ('app_label__icontains', 'model_name__icontains',),
        ('profile__users__email__icontains',),
    )
    list_filter = ('status',)
    fieldsets = (
        (_('general information'), {
            'fields': ('name', ('app_label', 'model_name'), 'codename',)
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = ('id', 'status', 'app_label', 'model_name', 'name', 'ordering')
    list_display_links = ('name',)
    readonly_fields = ('name', 'codename', 'creator', 'date_create', 'last_modifier', 'date_last_modify')
    inlines = (UsedFieldInline, RequiredFieldInline, StatusFlowInline, FilterInline)


class RequiredFieldAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    search_fields = ('role__app_label',)
    advanced_search_fields = (
        ('status',),
        ('role', 'from_status',),
        ('role__app_label__icontains', 'role__model_name__icontains',),
    )
    list_filter = ('status',)
    fieldsets = (
        (_('general information'), {
            'fields': ('role', 'from_status', 'fields')
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = ('id', 'status', 'role', 'app_label', 'model_name', 'from_status', 'fields', 'ordering')
    list_display_links = ('role',)
    autocomplete_fields = ('role',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')


class StatusFlowAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    search_fields = ('role__app_label',)
    advanced_search_fields = (
        ('status',),
        ('role', 'from_status',),
        ('role__app_label__icontains', 'role__model_name__icontains',),
    )
    list_filter = ('status',)
    fieldsets = (
        (_('general information'), {
            'fields': (
                'role',
                ('from_status', 'to_status',),
            )
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = ('id', 'status', 'role', 'app_label', 'model_name', 'from_status', 'to_status', 'ordering')
    list_display_links = ('role',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')
    autocomplete_fields = ('role',)


class UsedFieldAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    search_fields = ('role__app_label',)
    advanced_search_fields = (
        ('status',),
        ('role', 'from_status',),
        ('action',),
        ('role__app_label__icontains', 'role__model_name__icontains',),
    )
    list_filter = ('status',)
    fieldsets = (
        (_('general information'), {
            'fields': ('role', 'from_status', 'action', 'fields')
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = ('id', 'status', 'role', 'app_label', 'model_name', 'from_status', 'action', 'fields', 'ordering')
    list_display_links = ('role',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')
    autocomplete_fields = ('role',)


class FilterAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    search_fields = ('name',)
    advanced_search_fields = (
        ('status',),
        ('role', 'action',),
        ('role__app_label__icontains', 'role__model_name__icontains',),
    )
    list_filter = ('status',)
    fieldsets = (
        (_('general information'), {
            'fields': (
                'codename', 'role', 'action',
                'description', 'code',
            )
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = ('id', 'status', 'role', 'app_label', 'model_name', 'action', 'ordering')
    list_display_links = ('role',)
    readonly_fields = ('codename', 'creator', 'date_create', 'last_modifier', 'date_last_modify')
    autocomplete_fields = ('role',)


class MenuAdmin(
    MPTTModelAdmin, UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    """
    To allow the overriding of change_list_template, add 'mptt' in INSTALLED_APPS before 'django.contrib.admin'.
    """

    search_fields = ('title',)
    advanced_search_fields = (
        ('title__icontains',),
        ('parent__title__icontains',),
    )
    list_filter = ('status', 'language_code')
    fieldsets = (
        (_('general information'), {
            'fields': (
                'parent',
                'title',
                'language_code', 'router',
                'roles',
                'info',
            ),
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status',),
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
        }),
    )
    list_display = ('id', 'status', 'language_code', 'parent', 'title', 'role_list', 'ordering',)
    list_display_links = ('title',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify',)
    autocomplete_fields = ('parent', 'roles',)


admin.site.register(models.Profile, ProfileAdmin)
admin.site.register(models.Role, RoleAdmin)
admin.site.register(models.RequiredField, RequiredFieldAdmin)
admin.site.register(models.StatusFlow, StatusFlowAdmin)
admin.site.register(models.UsedField, UsedFieldAdmin)
admin.site.register(models.Filter, FilterAdmin)
admin.site.register(models.Menu, MenuAdmin)
