# -*- coding: utf-8 -*-

import urllib

import requests
from django.urls import reverse


class RemoteTestMixin:
    # PROFILE
    def v1_role_profile_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:profile-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_role_profile_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:profile-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_role_profile_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:profile-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_profile_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:profile-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_profile_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:profile-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_profile_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:profile-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_profile_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:profile-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_role_profile_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:profile-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_role_profile_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:profile-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp
    # ROLE

    def v1_role_role_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:role-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_role_role_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:role-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_role_role_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:role-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_role_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:role-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_role_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:role-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_role_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:role-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_role_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:role-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_role_role_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:role-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_role_role_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:role-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp
    # USER ROLE

    def v1_role_user_role_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:userrole-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_role_user_role_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:userrole-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_role_user_role_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:userrole-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_user_role_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:userrole-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_user_role_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:userrole-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_user_role_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:userrole-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_user_role_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:userrole-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_role_user_role_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:userrole-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_role_user_role_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:userrole-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp
    # REQUIRED FIELD

    def v1_role_required_field_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:requiredfield-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_role_required_field_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:requiredfield-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_role_required_field_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:requiredfield-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_required_field_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:requiredfield-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_required_field_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:requiredfield-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_required_field_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:requiredfield-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_required_field_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:requiredfield-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_role_required_field_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:requiredfield-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_role_required_field_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:requiredfield-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp
    # STATUS FLOW

    def v1_role_status_flow_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:statusflow-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_role_status_flow_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:statusflow-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_role_status_flow_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:statusflow-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_status_flow_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:statusflow-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_status_flow_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:statusflow-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_status_flow_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:statusflow-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_status_flow_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:statusflow-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_role_status_flow_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:statusflow-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_role_status_flow_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:statusflow-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp
    # USED FIELD

    def v1_role_used_field_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:usedfield-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_role_used_field_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:usedfield-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_role_used_field_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:usedfield-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_used_field_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:usedfield-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_used_field_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:usedfield-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_used_field_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:usedfield-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_used_field_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:usedfield-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_role_used_field_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:usedfield-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_role_used_field_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:usedfield-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp
    # FILTER

    def v1_role_filter_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:filter-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_role_filter_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:filter-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_role_filter_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:filter-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_filter_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:filter-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_filter_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:filter-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_filter_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:filter-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_filter_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:filter-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_role_filter_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:filter-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_role_filter_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:filter-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp
    # MENU

    def v1_role_menu_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:menu-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_role_menu_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:menu-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_role_menu_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:menu-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_menu_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:menu-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_menu_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:menu-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_menu_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:menu-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_role_menu_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:menu-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_role_menu_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:menu-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_role_menu_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-role:menu-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp
