# -*- coding: utf-8 -*-

from django.utils.translation import gettext_lazy as _
from rest_framework import serializers


class ThuxRoleSerializerMixin:
    def get_field_names(self, *args, **kwargs):
        try:
            view = self.context.get('view')
            user = view.request.user
            if user and user.is_superuser:
                return super().get_field_names(*args, **kwargs)
            fields = self.context.get('view').used_fields
            if fields == '__all__':
                return super().get_field_names(*args, **kwargs)
            return fields
        except Exception:
            return ()

    def validate(self, data):
        view = self.context.get('view')
        user = view.request.user
        if user and user.is_superuser:
            for field in view.required_fields:
                if data.get(field, None) is None:
                    raise serializers.ValidationError({field: _("field is required")})
        validate = super().validate(data)

        if user and user.is_superuser:
            return validate

        status = data.get('status', None)
        if status and (view.from_status or view.to_status):
            if status != view.from_status and status not in view.to_status:
                raise serializers.ValidationError({'status': _("invalid status")})
        return validate
