# -*- coding: utf-8 -*-
import logging

from django.core.management.base import BaseCommand

from thx.role.utils import InitialRole


class Command(BaseCommand):
    help = "Populate Role data"
    logger = logging.getLogger('file')

    def add_arguments(self, parser):
        parser.add_argument(
            '-c', '--console', action='store_true', default=False,
            help='Debug - write logging to console',
        )
        parser.add_argument(
            '-l', '--debug-level', default='info',
            help='Set debug level (debug, info, warnings) for console',
        )

    def handle(self, *args, **options):
        try:
            debug_level = getattr(logging, options.get('debug_level').upper())
            self.logger.setLevel(debug_level)
            self.logger.handlers[0].setLevel(debug_level)

            if options.get('console'):
                console_handler = logging.StreamHandler()
                console_handler.setLevel(debug_level)
                self.logger.addHandler(console_handler)
                self.logger.setLevel(debug_level)

            initializer = InitialRole()
            initializer.insert_all()

            self.logger.debug("Execution finished")

        except Exception as e:
            self.stdout.write(self.style.ERROR(
                f'Execution failed: {e}')
            )
