# Generated by Django 3.2.19 on 2023-07-14 12:32
from django.db import migrations


def migrate_profiles(apps, schema_editor):
    User = apps.get_model("account", "User")
    Profile = apps.get_model("role", "Profile")
    Role = apps.get_model("role", "Role")

    try:
        user_id = User.objects.filter(is_superuser=True).first().id
    except AttributeError:
        try:
            user_id = User.objects.filter(is_staff=True).first().id
        except AttributeError:
            try:
                user_id = User.objects.first().id
            except AttributeError:
                # No data to be migrated
                return

    # Crate profiles based on existing Roles data
    profiles = Role.objects.values_list("codename", "name").distinct("codename").order_by("codename")
    Profile.objects.bulk_create([
        Profile(
            codename=codename,
            name=name,
            status=1,
            creator_id=user_id,
            last_modifier_id=user_id
        )
        for codename, name in profiles
    ])

    # Crate Roles relations
    for codename, _ in profiles:
        Role.objects.filter(codename=codename).update(profile=Profile.objects.get(codename=codename))

    # Associate users with profiles
    for profile in Profile.objects.all():
        users = (
            User
            .objects
            .filter(roles__profile_id=profile.id)
            .distinct()
        )
        profile.users.through.objects.bulk_create([
            profile.users.through(
                profile_id=profile.id,
                user_id=user.id
            ) for user in users
        ])


class Migration(migrations.Migration):

    dependencies = [
        ('role', '0007_auto_20230714_1232'),
    ]

    operations = [
        migrations.RunPython(code=migrate_profiles)
    ]
